import { DataSource } from 'apollo-datasource';
import type { Queue as BullQueue, JobCounts, JobStatus, JobId } from 'bull';
import { CreateJobInput, MutationCleanQueueArgs, MutationCloseQueueArgs, MutationDiscardJobArgs, MutationEmptyQueueArgs, MutationLogArgs, MutationMoveJobToCompletedArgs, MutationMoveJobToFailedArgs, MutationPromoteJobArgs, MutationRemoveJobArgs, MutationRemoveJobsByPatternArgs, MutationResumeQueueArgs, MutationRetryJobArgs, MutationUpdateJobDataArgs, OrderEnum } from '../../typings/gql';
import { Maybe } from '../../typings/utils';
import redisInfo from 'redis-info';
export declare class BullMonitorError extends Error {
    constructor(msg: any);
}
export declare enum ErrorEnum {
    QUEUE_NOT_FOUND = "QUEUE_NOT_FOUND",
    JOB_NOT_FOUND = "JOB_NOT_FOUND"
}
export declare class BullDataSource extends DataSource {
    private _queues;
    private _queuesMap;
    constructor(_queues: BullQueue[]);
    private _convertQueuesToMap;
    private _throwInternalError;
    private _throwQueueNotFound;
    private _throwJobNotFound;
    getQueueByName(name: string, throwIfNotFound?: boolean): BullQueue<any> | undefined;
    getQueues(): BullQueue[];
    getQueueJobs({ queue, limit, offset, status, id, order, }: {
        status?: JobStatus;
        queue: string;
        limit?: number;
        offset?: number;
        order?: OrderEnum;
        id?: JobId;
    }): Promise<import("bull").Job<any>[] | undefined>;
    getJob(queueName: string, id: JobId, throwIfNotFound?: boolean): Promise<import("bull").Job<any> | null | undefined>;
    getJobLogs(queueName: string, id: number): Promise<{
        logs: string[];
        count: number;
    } | undefined>;
    getQueueJobsCounts(name: string): Promise<Maybe<JobCounts>>;
    getQueueFailedCount(name: string): Promise<Maybe<number>>;
    getQueueCompletedCount(name: string): Promise<Maybe<number>>;
    getQueueDelayedCount(name: string): Promise<Maybe<number>>;
    getQueueActiveCount(name: string): Promise<Maybe<number>>;
    getQueueWaitingCount(name: string): Promise<Maybe<number>>;
    getQueuePausedCount(name: string): Promise<Maybe<number>>;
    getQueueWaitingOrDelayedJobsCount(name: string): Promise<Maybe<number>>;
    getRedisInfo(): Promise<redisInfo.RedisInfo | null>;
    createJob({ queue: queueName, name, data, options, }: CreateJobInput): Promise<import("bull").Job<any> | undefined>;
    removeJobsByPattern(args: MutationRemoveJobsByPatternArgs): Promise<boolean>;
    pauseQueue(name: string): Promise<BullQueue<any> | undefined>;
    cleanQueue(args: MutationCleanQueueArgs): Promise<import("bull").Job<any>[] | undefined>;
    emptyQueue(args: MutationEmptyQueueArgs): Promise<BullQueue<any> | undefined>;
    closeQueue(args: MutationCloseQueueArgs): Promise<BullQueue<any> | undefined>;
    resumeQueue(args: MutationResumeQueueArgs): Promise<BullQueue<any> | undefined>;
    promoteJob(args: MutationPromoteJobArgs): Promise<import("bull").Job<any> | null | undefined>;
    discardJob(args: MutationDiscardJobArgs): Promise<import("bull").Job<any> | null | undefined>;
    updateJobData(args: MutationUpdateJobDataArgs): Promise<import("bull").Job<any> | null | undefined>;
    createJobLog(args: MutationLogArgs): Promise<import("bull").Job<any> | null | undefined>;
    retryJob(args: MutationRetryJobArgs): Promise<import("bull").Job<any> | null | undefined>;
    removeJobById(args: MutationRemoveJobArgs): Promise<import("bull").Job<any> | null | undefined>;
    moveJobToCompleted(args: MutationMoveJobToCompletedArgs): Promise<import("bull").Job<any> | null | undefined>;
    moveJobToFailed(args: MutationMoveJobToFailedArgs): Promise<import("bull").Job<any> | null | undefined>;
}
